@@ -44,6 +44,7 @@ class ResourceMetadataIn(BaseMetadata):
     )
     abstract: str = Field(default=None, title="Abstract", description="A string containing a summary of a resource")
     language: str = Field(
+        default="eng",
         title="Language",
         description="A 3-character string for the language in which the metadata and content of a resource are expressed",
     )
@@ -76,7 +77,9 @@ class ResourceMetadataIn(BaseMetadata):
         description="A dictionary containing key-value pair metadata associated with a resource",
     )
     rights: Rights = Field(
-        title="Rights", description="An object containing information about rights held in an over a resource"
+        default_factory=Rights.Creative_Commons_Attribution_CC_BY,
+        title="Rights",
+        description="An object containing information about rights held in an over a resource",
     )
     awards: List[AwardInfo] = Field(
         default=[],
